@@ -1,83 +1,84 @@
 var Path      = require('path'),
     _         = require('lodash'),
     multipipe = require('multipipe'),
-    csv       = require('csv'),
+    csv       = require('fast-csv'),
+    logger    = require('../../log').Logger,
     command   = require('../../command'),
     appConfig = require('../../runtime/app_config');
 
 var PARSER_INSTRUCTIONS = {
   'revisions': function(row) {
     return {
-      path:      row[0],
-      revisions: parseInt(row[1])
+      path:      row.entity,
+      revisions: parseInt(row['n-revs'])
     };
   },
   'soc': function(row) {
     return {
-      path: row[0],
-      soc: parseInt(row[1])
+      path: row.entity,
+      soc:  parseInt(row.soc)
     };
   },
   'coupling': function(row) {
     return {
-      path:           row[0],
-      coupledPath:    row[1],
-      couplingDegree: parseInt(row[2]),
-      revisionsAvg:   parseInt(row[3])
+      path:           row.entity,
+      coupledPath:    row.coupled,
+      couplingDegree: parseInt(row.degree),
+      revisionsAvg:   parseInt(row['average-revs'])
     };
   },
   'authors': function(row) {
     return {
-      path:      row[0],
-      authors:   parseInt(row[1]),
-      revisions: parseInt(row[2])
+      path:      row.entity,
+      authors:   parseInt(row['n-authors']),
+      revisions: parseInt(row['n-revs'])
     };
   },
   'main-dev': function(row) {
     return {
-      path:       row[0],
-      author:     row[1],
-      addedLines: parseInt(row[2]),
-      ownership:  Math.round(parseFloat(row[4]) * 100)
+      path:       row.entity,
+      author:     row['main-dev'],
+      addedLines: parseInt(row.added),
+      ownership:  Math.round(parseFloat(row.ownership) * 100)
     };
   },
   'entity-effort': function(row) {
     return {
-      path:      row[0],
-      author:    row[1],
-      revisions: parseInt(row[2])
+      path:      row.entity,
+      author:    row.author,
+      revisions: parseInt(row['author-revs'])
     };
   },
   'entity-ownership': function(row) {
     return {
-      path:         row[0],
-      author:       row[1],
-      addedLines:   parseInt(row[2]),
-      deletedLines: parseInt(row[3])
+      path:         row.entity,
+      author:       row.author,
+      addedLines:   parseInt(row.added),
+      deletedLines: parseInt(row.deleted)
     };
   },
   'communication': function(row) {
     return {
-      author:           row[0],
-      coupledAuthor:    row[1],
-      sharedCommits:    parseInt(row[2]),
-      couplingStrength: parseInt(row[4])
+      author:           row.author,
+      coupledAuthor:    row.peer,
+      sharedCommits:    parseInt(row.shared),
+      couplingStrength: parseInt(row.strength)
     };
    },
    'absolute-churn': function(row) {
     return {
-      date:         row[0],
-      addedLines:   parseInt(row[1]),
-      deletedLines: parseInt(row[2]),
-      commits:      parseInt(row[3])
+      date:         row.date,
+      addedLines:   parseInt(row.added),
+      deletedLines: parseInt(row.deleted),
+      commits:      parseInt(row.commits)
     };
    },
    'entity-churn': function(row) {
     return {
-      path:         row[0],
-      addedLines:   parseInt(row[1]),
-      deletedLines: parseInt(row[2]),
-      commits:      parseInt(row[3])
+      path:         row.entity,
+      addedLines:   parseInt(row.added),
+      deletedLines: parseInt(row.deleted),
+      commits:      parseInt(row.commits)
     };
    }
 };
@@ -115,10 +116,19 @@ module.exports = function(instruction) {
       },
       additionalOptions
     ];
+
     return multipipe(
       command.stream('codemaat', args),
-      csv.parse(),
-      csv.transform(_.after(2, PARSER_INSTRUCTIONS[instruction]))
-    );
+      csv({ headers: true, ignoreEmpty: true, strictColumnHandling: true })
+        .transform(function(data) {
+          if (_.isPlainObject(data)) { return PARSER_INSTRUCTIONS[instruction](data); }
+        })
+      )
+      .on('error', function(err) {
+        logger.error('Error streaming CodeMaat output: ' + err.toString());
+      })
+      .once('data-invalid', function(data) {
+        logger.warn('Invalid CodeMaat output: >>' + data);
+      });
   };
 };
