@@ -1,4 +1,5 @@
-var _ = require('lodash');
+var _      = require('lodash'),
+    logger = require('../log').Logger;
 
 module.exports = function(weightedProperty, normalised) {
   var collection = [];
@@ -7,7 +8,19 @@ module.exports = function(weightedProperty, normalised) {
   var extractWeight = function(item, property) {
     if (_.isFunction(property)) { return property(item); }
     if (_.isString(property)) { return item[property]; }
-    throw "Property must be a function or a property name";
+    throw 'Property must be a function or a property name';
+  };
+
+  var weightCalculatorFn = function() {
+    var maxWeight = _.maxBy(collection, 'weight').weight;
+    if (maxWeight === 0) {
+      logger.warn("Can't determine weight value of collection. Assigining 0 to every item.");
+      return _.constant(0);
+    }
+    if (isNormalised) {
+      return function(obj) { return obj.weight * 1.0 / maxWeight; };
+    }
+    return _.property('weight');
   };
 
   this.addItem = function(item) {
@@ -18,9 +31,9 @@ module.exports = function(weightedProperty, normalised) {
   this.assignWeights = function(weightPropertyName) {
     if (!_.isEmpty(collection)) {
       var property = weightPropertyName || 'weight';
-      var maxWeight = _.maxBy(collection, 'weight').weight;
+      var weightCalculator = weightCalculatorFn();
       _.each(collection, function(obj) {
-        obj.item[property] = isNormalised ? (obj.weight * 1.0 / maxWeight) : obj.weight;
+        obj.item[property] = weightCalculator(obj);
       });
     }
   };
