@@ -12,5 +12,6 @@ module.exports = {
   log: log,
   debug: function(msg, detail) { log(chalk.green(msg) + detail); },
   info: function(msg, detail) { log(chalk.yellow(msg) + chalk.grey(detail)); },
-  error: function(msg) { log(chalk.red(msg)); }
+  warn: function(msg) { log(chalk.bgYellow.magenta(msg)); },
+  error: function(msg) { log(chalk.bgWhite.red(msg)); }
 };
