@@ -14,7 +14,7 @@ module.exports = {
   expand: function(originalPaths, expander) {
     return _.reduce(originalPaths, function(array, path) {
       var expandedPaths = _.filter(expander(path), function(p) {
-        return fs.statSync(p).isFile();
+        return fs.existsSync(p) && fs.statSync(p).isFile();
       });
       return array.concat(expandedPaths);
     }, []);
