@@ -14,7 +14,9 @@ module.exports = function(task, context) {
         var returnedValue = task.taskFunction.apply(null, [publisher].concat(_.toArray(argsArray)));
         var promise = isStream(returnedValue) ? utils.stream.streamToPromise(returnedValue) : Q(returnedValue);
 
-        return promise.then(publisher.createManifest.bind(publisher));
+        return promise
+          .then(publisher.createManifest.bind(publisher))
+          .catch(logger.error);
       } catch (e) { logger.error(e); }
     }
   };
