@@ -9,16 +9,24 @@ module.exports = function(dateFormat) {
       dateFrom = moment(),
       dateTo = moment();
 
+  var parseDate = function(d) {
+    var date = moment(d, dateFormat);
+    if (!date.isValid()) {
+      throw new CFValidationError('Error parsing date: ' + d);
+    }
+    return date;
+  };
+
   this.from = function(from) {
     if (_.isString(from)) {
-      dateFrom = moment(from, dateFormat);
+      dateFrom = parseDate(from);
     }
     return this;
   };
 
   this.to = function(to) {
     if (_.isString(to)) {
-      dateTo = moment(to, dateFormat);
+      dateTo = parseDate(to);
     }
     return this;
   };
