@@ -14,9 +14,7 @@ var DEFAULT_CONFIG = {
   maxConcurrency: os.cpus().length,
   debugMode: false,
   logEnabled: true,
-  serverPort: 3000,
-  javascriptParser: {},
-  codeMaatOptions: {}
+  serverPort: 3000
 };
 
 var readConfigFromFile = function() {
@@ -35,11 +33,11 @@ var readConfigFromEnv = function() {
     debugMode: _.isUndefined(process.env.COMMAND_DEBUG) ? undefined : true,
     logEnabled: _.isUndefined(process.env.LOG_DISABLED) ? undefined : false,
     serverPort: process.env.SERVER_PORT,
-    codeMaatOptions: _.isString(codeMaatOptions) ? utils.arrayPairsToObject(codeMaatOptions.split(' ')) : undefined
+    codeMaat: { options: _.isString(codeMaatOptions) ? utils.arrayPairsToObject(codeMaatOptions.split(' ')) : undefined }
   };
 };
 
-var singletonConfig = _.defaults(readConfigFromEnv(), readConfigFromFile(), DEFAULT_CONFIG);
+var singletonConfig = _.defaultsDeep(readConfigFromEnv(), readConfigFromFile(), DEFAULT_CONFIG);
 
 module.exports = {
   get: function(property) {
