@@ -35,7 +35,7 @@ module.exports = function(config, params) {
   );
 
   this.boundaries = (configuration.architecturalBoundaries || {})[this.parameters.boundary];
-  this.developerInfo = new models.DeveloperInfo(configuration.teamsComposition);
+  this.developerInfo = new models.DeveloperInfo(configuration.contributors);
 
   this.languages = _.map(configuration.languages, function(lang) {
     if (_.isUndefined(models.LanguageDefinitions.getDefinition(lang))) {
@@ -44,5 +44,5 @@ module.exports = function(config, params) {
     return lang;
   });
 
-  this.commitMessagesFilters = configuration.commitMessagesFilters;
+  this.commitMessageFilters = configuration.commitMessageFilters;
 };
