@@ -26,4 +26,15 @@ module.exports = function(taskDef, context, helpers) {
   });
 
   taskDef.addTask('code-stats-reports', ['sloc-report'].concat(complexityAnalysisTasks));
+
+  taskDef.addAnalysisTask('sloc-trend-analysis',
+    {
+      description: 'Analyse the sloc trend in time for a particular file',
+      reportName: 'sloc-trend',
+      parameters: [{ name: 'targetFile', required: true }, { name: 'dateFrom' }, { name: 'dateTo' }],
+      reportFile: 'sloc-trend-data.json'
+    }, function(publisher) {
+    var stream = helpers.revision.revisionAnalysisStream(sloc.analyser());
+    return utils.json.objectArrayToFileStream(publisher.addReportFile(), stream);
+  });
 };
