@@ -16,7 +16,7 @@ module.exports = function(parent, definition) {
   }
 
   if (_.isPlainObject(definition.labels)) {
-    D3Element.applyProperties(axisElement.selectAll('.tick text'), definition.labels);
+    D3Element.applyDefinition(axisElement.selectAll('.tick text'), definition.labels);
   }
 
   this.repaint = function() {
