@@ -11,8 +11,6 @@ module.exports = function(id, diagramSettings) {
 
   this.controls = new ControlsProxy(diagramSettings.controls || {});
   this.cssClass = diagramSettings.configuration.style.cssClass;
-  this.width = diagramSettings.configuration.style.width + 'px';
-  this.height = diagramSettings.configuration.style.height + 'px';
   this.hasData = ko.observable(false);
   this.model = ko.observable();
 
