@@ -1,12 +1,12 @@
 module.exports = function(config, series, colorScale) {
-  var elementsOffset = function(d, i) { return { x: 35, y: i * 15 }; };
+  var elementsOffset = function(d, i) { return { x: 10, y: i * 15 }; };
 
   this.legendDefinition = {
     name: 'legend',
     componentType: 'data',
     properties: {
       offset: { x: config.style.width - config.style.margin.right,  y: config.style.margin.top },
-      attributes: { class: 'legend', width: config.style.width }
+      attributes: { class: 'legend' }
     },
     series: series,
     graphicElements: [
