@@ -14,12 +14,12 @@ module.exports = function(manifest) {
       dateRange: manifest.parseDateRange()
     },
     graphModels: [
-      { valueProperty: 'sloc', valueLabel: 'Lines of code' },
-      { valueProperty: 'totalComplexity', valueLabel: 'Complexity' }
+      { valueProperty: 'sourceLines', diagramLabel: 'Lines of code', valueLabel: 'Source lines of code' },
+      { valueProperty: 'totalComplexity', diagramLabel: 'Cyclomatic Complexity', valueLabel: 'Complexity' }
     ].map(function(cfg) {
       return {
         id: 'hotspot-analysis-' + cfg.valueProperty,
-        label: cfg.valueLabel,
+        label: cfg.diagramLabel,
         dataFile: manifest.dataFiles[0],
         controlTemplates: {
           filters: [
