@@ -32,14 +32,14 @@ module.exports = function(manifest) {
         dataFile: manifest.dataFiles[0],
         controlTemplates: {
           filters: [
-            { name: 'metricRangeFilterTemplate', data: { labels: ['Lines of code'] } },
+            { name: 'metricRangeFilterTemplate', data: { labels: ['Total lines of code'] } },
             { name: 'colorMapFilterTemplate', data: { labels: [attributes.label] } }
           ]
         },
         viewTemplates: ['elementInfo3TooltipTemplate'],
         diagram:{
           Model: Model,
-          layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: 'sloc' }),
+          layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: 'totalLines' }),
           graphHandlers: [new ZoomHandler({ diameter: 950 })],
           configuration: {
             style: {
@@ -47,12 +47,12 @@ module.exports = function(manifest) {
               width: 960,
               height: 960,
               diameter: 950,
-              nodeDepthColorRange: ['hsl(250,0%,90%)', 'hsl(260,0%,60%)']
+              nodeDepthColorRange: ['hsl(0,0%,100%)', 'hsl(0,0%,80%)']
             },
             colorScaleFactory: function(series) {
               return ColorScaleFactory.sequentialRainbow(series);
             },
-            series: { valueProperty: 'sloc', colorProperty: attributes.colorProperty },
+            series: { valueProperty: 'totalLines', colorProperty: attributes.colorProperty },
             tooltipInfo: {
               templateId: 'element-info-3-tooltip',
               templateProperties: [
@@ -69,7 +69,7 @@ module.exports = function(manifest) {
                 instance: new filters.MetricRange(),
                 group: 'metricRange',
                 dataTransform: function(series) {
-                  return _.map(_.filter(series, _.method('isLeaf')), 'data.sloc');
+                  return _.map(_.filter(series, _.method('isLeaf')), 'data.totalLines');
                 }
               },
               colorFilter: {
