@@ -23,7 +23,7 @@ module.exports = function(manifest) {
         viewTemplates: ['elementInfo3TooltipTemplate'],
         diagram: {
           Model: Model,
-          layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: 'sloc' }),
+          layoutAdapter: new LayoutAdapter({ diameter: 950, valueProperty: 'totalLines' }),
           graphHandlers: [new ZoomHandler({ diameter: 950 })],
           configuration: {
             style: {
@@ -35,7 +35,7 @@ module.exports = function(manifest) {
               weightedNodeColor: '#990012',
               nodeHighlight: { name: modulePath, color: '#1269FC' }
             },
-            series: { calculatedWeightProperty: 'weight', valueProperty: 'sloc' },
+            series: { calculatedWeightProperty: 'weight', valueProperty: 'totalLines' },
             tooltipInfo: {
               templateId: 'element-info-3-tooltip',
               templateProperties: [
